@@ -50,7 +50,7 @@ TRANSACTION_STATUS_BROADCASTING = "BROADCASTING"
 TRANSACTION_STATUS_CONFIRMING = "CONFIRMING"
 TRANSACTION_STATUS_CONFIRMED = "CONFIRMED" # Deprecated
 TRANSACTION_STATUS_COMPLETED = "COMPLETED"
-TRANSACTION_STATUS_PENDING_AML_CHECKUP = "PENDING_AML_CHECKUP"
+TRANSACTION_STATUS_PENDING_AML_SCREENING = "PENDING_AML_SCREENING"
 TRANSACTION_STATUS_PARTIALLY_COMPLETED = "PARTIALLY_COMPLETED"
 TRANSACTION_STATUS_CANCELLING = "CANCELLING"
 TRANSACTION_STATUS_CANCELLED = "CANCELLED"
@@ -70,7 +70,7 @@ TRANSACTION_STATUS_BROADCASTING,
 TRANSACTION_STATUS_CONFIRMING,
 TRANSACTION_STATUS_CONFIRMED,
 TRANSACTION_STATUS_COMPLETED,
-TRANSACTION_STATUS_PENDING_AML_CHECKUP,
+TRANSACTION_STATUS_PENDING_AML_SCREENING,
 TRANSACTION_STATUS_PARTIALLY_COMPLETED,
 TRANSACTION_STATUS_CANCELLING,
 TRANSACTION_STATUS_CANCELLED,
