@@ -235,9 +235,47 @@ class FireblocksSDK(object):
 
         return self._post_request(f"/v1/fiat_accounts/{account_id}/deposit_from_linked_dda", body, idempotency_key)
 
+    def get_transactions_with_page_info(self, before=0, after=None, status=None, limit=None, txhash=None,
+                         assets=None, source_type=None, source_id=None, dest_type=None, dest_id=None, next_or_previous_path=None):
+        """Gets a list of transactions matching the given filters or path.
+        Note that "next_or_previous_path" is mutually exclusive with other parameters.
+        If you wish to iterate over the nextPage/prevPage pages, please provide only the "next_or_previous_path" parameter from `pageDetails` response
+        example:
+            get_transactions_with_page_info(next_or_previous_path=response[pageDetails][nextPage])
+
+        Args:
+            before (int, optional): Only gets transactions created before given timestamp (in milliseconds)
+            after (int, optional): Only gets transactions created after given timestamp (in milliseconds)
+            status (str, optional): Only gets transactions with the specified status, which should one of the following:
+                SUBMITTED, QUEUED, PENDING_SIGNATURE, PENDING_AUTHORIZATION, PENDING_3RD_PARTY_MANUAL_APPROVAL,
+                PENDING_3RD_PARTY, BROADCASTING, CONFIRMING, COMPLETED, PENDING_AML_CHECKUP, PARTIALLY_COMPLETED,
+                CANCELLING, CANCELLED, REJECTED, FAILED, TIMEOUT, BLOCKED
+            limit (int, optional): Limit the amount of returned results. If not specified, a limit of 200 results will be used
+            txhash (str, optional): Only gets transactions with the specified txHash
+            assets (str, optional): Filter results for specified assets
+            source_type (str, optional): Only gets transactions with given source_type, which should be one of the following:
+                VAULT_ACCOUNT, EXCHANGE_ACCOUNT, INTERNAL_WALLET, EXTERNAL_WALLET, UNKNOWN_PEER, FIAT_ACCOUNT,
+                NETWORK_CONNECTION, COMPOUND
+            source_id (str, optional): Only gets transactions with given source_id
+            dest_type (str, optional): Only gets transactions with given dest_type, which should be one of the following:
+                VAULT_ACCOUNT, EXCHANGE_ACCOUNT, INTERNAL_WALLET, EXTERNAL_WALLET, UNKNOWN_PEER, FIAT_ACCOUNT,
+                NETWORK_CONNECTION, COMPOUND
+            dest_id (str, optional): Only gets transactions with given dest_id
+            next_or_previous_path (str, optional): get transactions matching the path, provided from pageDetails
+        """
+        if next_or_previous_path is not None:
+            if not next_or_previous_path:
+                return {'transactions': [], 'pageDetails': {'prevPage': '', 'nextPage': ''}}
+            index = next_or_previous_path.index('/v1/')
+            length = len(next_or_previous_path) - 1
+            suffix_path = next_or_previous_path[index:length]
+            return self._get_request(suffix_path, True)
+        else:
+            return self._get_transactions(before, after, status, limit, None, txhash, assets, source_type, source_id, dest_type, dest_id, True)
+
     def get_transactions(self, before=0, after=0, status=None, limit=None, order_by=None, txhash=None,
                          assets=None, source_type=None, source_id=None, dest_type=None, dest_id=None):
-        """Gets a list of transactions matching the given filter
+        """Gets a list of transactions matching the given filters
 
         Args:
             before (int, optional): Only gets transactions created before given timestamp (in milliseconds)
@@ -259,9 +297,10 @@ class FireblocksSDK(object):
                 NETWORK_CONNECTION, COMPOUND
             dest_id (str, optional): Only gets transactions with given dest_id
         """
+        return self._get_transactions(before, after, status, limit, order_by, txhash, assets, source_type, source_id, dest_type, dest_id)
 
+    def _get_transactions(self, before, after, status, limit, order_by, txhash, assets, source_type, source_id, dest_type, dest_id, page_mode=False):
         path = "/v1/transactions"
-
         params = {}
 
         if status and status not in TRANSACTION_STATUS_TYPES:
@@ -289,11 +328,10 @@ class FireblocksSDK(object):
             params['destType'] = dest_type
         if dest_id:
             params['destId'] = dest_id
-
         if params:
             path = path + "?" + urllib.parse.urlencode(params)
 
-        return self._get_request(path)
+        return self._get_request(path, page_mode)
 
     def get_internal_wallets(self):
         """Gets all internal wallets for your tenant"""
@@ -593,7 +631,7 @@ class FireblocksSDK(object):
             )
 
 
-    def create_transaction(self, asset_id, amount=None, source=None, destination=None, fee=None, gas_price=None, wait_for_status=False, tx_type=TRANSACTION_TRANSFER, note=None, cpu_staking=None, network_staking=None, auto_staking=None, customer_ref_id=None, replace_tx_by_hash=None, extra_parameters=None, destinations=None, fee_level=None, fail_on_fee=None, max_fee=None, gas_limit=None, idempotency_key=None, external_tx_id=None):
+    def create_transaction(self, asset_id, amount=None, source=None, destination=None, fee=None, gas_price=None, wait_for_status=False, tx_type=TRANSACTION_TRANSFER, note=None, network_fee=None, customer_ref_id=None, replace_tx_by_hash=None, extra_parameters=None, destinations=None, fee_level=None, fail_on_fee=None, max_fee=None, gas_limit=None, idempotency_key=None, external_tx_id=None, treat_as_gross_amount=None):
         """Creates a new transaction
 
         Args:
@@ -618,6 +656,7 @@ class FireblocksSDK(object):
             gas_limit (number, optional): For ETH-based assets only.
             idempotency_key (str, optional)
             external_tx_id (str, optional): A unique key for transaction provided externally
+            treat_as_gross_amount (bool, optional): Determine if amount should be treated as gross or net
         """
 
         if tx_type not in TRANSACTION_TYPES:
@@ -669,14 +708,8 @@ class FireblocksSDK(object):
                 raise FireblocksApiException("Expected transaction destination of type DestinationTransferPeerPath or TransferPeerPath, but got type: " + type(destination))
             body["destination"] = destination.__dict__
 
-        if cpu_staking:
-            body["cpuStaking"] = cpu_staking
-
-        if network_staking:
-            body["networkStaking"] = network_staking
-
-        if auto_staking:
-            body["autoStaking"] = auto_staking
+        if network_fee:
+            body["networkFee"] = network_fee
 
         if customer_ref_id:
             body["customerRefId"] = customer_ref_id
@@ -684,6 +717,9 @@ class FireblocksSDK(object):
         if replace_tx_by_hash:
             body["replaceTxByHash"] = replace_tx_by_hash
 
+        if treat_as_gross_amount:
+            body["treatAsGrossAmount"] = treat_as_gross_amount
+
         if destinations:
             if any([not isinstance(x, TransactionDestination) for x in destinations]):
                 raise FireblocksApiException("Expected destinations of type TransactionDestination")
@@ -1019,7 +1055,19 @@ class FireblocksSDK(object):
 
         return self._get_request(url)
 
-    def _get_request(self, path):
+    def resend_webhooks(self):
+        """Resend failed webhooks of your tenant"""
+
+        return self._post_request("/v1/webhooks/resend")
+
+    def get_users(self):
+        """Gets all users of your tenant"""
+
+        url = "/v1/users"
+
+        return self._get_request(url)
+
+    def _get_request(self, path, page_mode=False):
         token = self.token_provider.sign_jwt(path)
         headers = {
             "X-API-Key": self.api_key,
@@ -1027,10 +1075,14 @@ class FireblocksSDK(object):
         }
 
         response = requests.get(self.base_url + path, headers=headers)
+        response_data = response.json()
         if response.status_code >= 300:
             raise FireblocksApiException("Got an error from fireblocks server: " + response.text)
         else:
-            return response.json()
+            if page_mode:
+                return {'transactions': response_data, 'pageDetails': {'prevPage': response.headers.get('prev-page', ''), 'nextPage': response.headers.get('next-page', '')}}
+            else:
+                return response_data
 
     def _delete_request(self, path):
         token = self.token_provider.sign_jwt(path)
